---
weight: 1905
title: "How to Contribute"
icon: volunteer_activism
description: "Contribute to code, improve documentation, help others, submit to showcase, and contribute financially."
lead: "Contribute to code, improve documentation, help others, submit to showcase, and contribute financially."
date: 2022-10-19T21:49:38+01:00
lastmod: 2023-08-24T16:34:38+01:00
draft: false
images: []
toc: true
---

## Contribute to code

### Create a Pull Request

- Follow the [GitHub flow](https://guides.github.com/introduction/flow/).
- Follow the [Conventional Commits Specification](https://www.conventionalcommits.org/en/v1.0.0/)

## Improve documentation

- Follow the [GitHub flow](https://guides.github.com/introduction/flow/).
- Follow the [Conventional Commits Specification](https://www.conventionalcommits.org/en/v1.0.0/)

### Create an issue

- [Bug report](https://github.com/oliveira-sh/pymocd/issues/)
- [Feature request](https://github.com/oliveira-sh/pymocd/issues/new)


## Submit to showcase

Share what you’ve built with us.